---
title: Post Authentication Hook
pageTitle: WunderGraph - Post Authentication Hook
description:
---

The `postAuthentication` hook gets called after the user has been authenticated.
As it's not a mutating hook,
this hook has no influence on the outcome of the authentication process.

The purpose of this hook is to be able to store information in other systems,
logging, etc...

Similar to all other hooks,
the `customResolve` hook is called with the following parameters:

- `user`: The user object when the user is authenticated
- `clientRequest`: The original client request object, including Headers
- `log`: The logger object
- `internalClient`: The internal client object
- `response`: The response object (only for postResolve hooks)
- `input`: The input object (only for Operation hooks)

With the `internalClient`,
you're able to securely call into all defined Operations,
e.g. to talk to a database or another service to enrich a response or manipulate the inputs of an Operation.

```typescript
// wundergraph.server.ts
export default configureWunderGraphServer<HooksConfig, InternalClient>(() => ({
  hooks: {
    authentication: {
      postAuthentication: async ({ user, log }) => {
        log.info(`User ${user.id} has been authenticated`)
      },
    },
  },
}))
```
